@@ -1,6 +1,6 @@
 /* rep_subrs.h -- mostly LISP subr declarations
    Copyright (C) 1993, 1994 John Harper <john@dcs.warwick.ac.uk>
-   $Id: rep_subrs.h,v 1.58 2000/07/15 11:42:23 john Exp $
+   $Id: rep_subrs.h,v 1.75 2002/10/07 07:42:09 jsh Exp $
 
    This file is part of Jade.
 
@@ -142,7 +142,7 @@ extern repv Qregexp_error;
 extern repv Fstring_match(repv re, repv str, repv start, repv nocasep);
 extern repv Fstring_looking_at(repv re, repv string,
 				repv start, repv nocasep);
-extern repv Fexpand_last_match(repv template);
+extern repv Fexpand_last_match(repv template_);
 extern repv Fmatch_start(repv exp);
 extern repv Fmatch_end(repv exp);
 extern repv Fquote_regexp(repv str);
@@ -164,6 +164,7 @@ extern repv rep_call_lisp1(repv, repv);
 extern repv rep_call_lisp2(repv, repv, repv);
 extern repv rep_call_lisp3(repv, repv, repv, repv);
 extern repv rep_call_lisp4(repv, repv, repv, repv, repv);
+extern repv rep_call_lispn (repv fun, int argc, repv *argv);
 extern repv rep_handle_var_int(repv, int *);
 extern repv rep_handle_var_long_int(repv, long *);
 extern void rep_handle_error(repv, repv);
@@ -200,6 +201,8 @@ extern repv Fstep(repv);
 extern repv Fsignal(repv error, repv data);
 extern repv Fbacktrace(repv strm);
 extern repv Vmax_lisp_depth(repv val);
+extern int rep_list_length(repv);
+extern rep_bool rep_assign_args (repv list, int required, int total, ...);
 
 /* from lispcmds.c */
 extern repv Qor, Qand;
@@ -209,11 +212,8 @@ extern repv Qsite_lisp_directory, Qdocumentation_file, Qdocumentation_files;
 extern repv Fquote(repv, repv);
 extern repv Fcar(repv);
 extern repv Fcdr(repv);
-extern repv Flist(repv);
-extern repv Flist_star(repv);
 extern repv Fmake_list(repv, repv);
-extern repv Fappend(repv);
-extern repv Fnconc(repv);
+extern repv Fnconc(repv args);
 extern repv Frplaca(repv, repv);
 extern repv Frplacd(repv, repv);
 extern repv Freverse(repv);
@@ -235,14 +235,12 @@ extern repv Fdelete(repv, repv);
 extern repv Fdelq(repv, repv);
 extern repv Fdelete_if(repv, repv);
 extern repv Fdelete_if_not(repv, repv);
-extern repv Fvector(repv);
 extern repv Fmake_vector(repv, repv);
 extern repv Farrayp(repv);
 extern repv Faset(repv, repv, repv);
 extern repv Faref(repv, repv);
 extern repv Fmake_string(repv, repv);
 extern repv Fsubstring(repv string, repv start, repv end);
-extern repv Fconcat(repv);
 extern repv Flength(repv);
 extern repv Fcopy_sequence(repv);
 extern repv Felt(repv, repv);
@@ -253,14 +251,6 @@ extern repv Fload(repv file, repv noerr_p, repv nopath_p,
 extern repv Fequal(repv, repv);
 extern repv Feq(repv, repv);
 extern repv Fstring_head_eq(repv, repv);
-extern repv Fnum_eq(repv args);
-extern repv Fnum_noteq(repv args);
-extern repv Fgtthan(repv);
-extern repv Fgethan(repv);
-extern repv Fltthan(repv);
-extern repv Flethan(repv);
-extern repv Fmax(repv);
-extern repv Fmin(repv);
 extern repv Fnull(repv);
 extern repv Fatom(repv);
 extern repv Fconsp(repv);
@@ -309,6 +299,7 @@ extern repv Qexit, Qquit, Qtop_level, Qcommand_line_args;
 extern repv Qbatch_mode, Qinterpreted_mode, Qprogram_name;
 extern repv Qerror_mode, Qinterrupt_mode;
 extern repv Frecursive_edit(void);
+extern repv rep_top_level_recursive_edit (void);
 extern repv Frecursion_depth(void);
 extern repv Fget_command_line_option (repv, repv);
 
@@ -323,7 +314,7 @@ enum rep_message {
     rep_restore_message,
     rep_redisplay_message
 };
-void (*rep_message_fun)(enum rep_message fn, ...);
+extern void (*rep_message_fun)(enum rep_message fn, ...);
 
 /* from misc.c */
 extern u_char *rep_str_dupn(const u_char *old, int len);
@@ -368,6 +359,7 @@ extern int rep_compare_numbers (repv n1, repv n2);
 extern char *rep_print_number_to_string (repv obj, int radix, int prec);
 extern repv rep_number_foldl (repv args, repv (*op)(repv, repv));
 extern repv rep_integer_foldl (repv args, repv (*op)(repv, repv));
+extern repv rep_foldl (repv args, repv (*op)(repv, repv));
 extern repv rep_number_add (repv x, repv y);
 extern repv rep_number_neg (repv x);
 extern repv rep_number_sub (repv x, repv y);
@@ -381,18 +373,11 @@ extern repv rep_number_max (repv x, repv y);
 extern repv rep_number_min (repv x, repv y);
 extern repv rep_integer_gcd (repv x, repv y);
 extern repv Feql(repv arg1, repv arg2);
-extern repv Fplus(repv);
-extern repv Fminus(repv);
-extern repv Fproduct(repv);
-extern repv Fdivide(repv);
 extern repv Fremainder(repv n1, repv n2);
 extern repv Fmod(repv n1, repv n2);
 extern repv Fquotient(repv n1, repv n2);
 extern repv Flognot(repv);
 extern repv Fnot(repv);
-extern repv Flogior(repv);
-extern repv Flogxor(repv);
-extern repv Flogand(repv);
 extern repv Fplus1(repv);
 extern repv Fsub1(repv);
 extern repv Fash(repv, repv);
@@ -410,7 +395,6 @@ extern repv Facos (repv);
 extern repv Fatan (repv, repv);
 extern repv Fsqrt (repv);
 extern repv Fexpt (repv, repv);
-extern repv Fgcd (repv);
 extern repv Fzerop(repv);
 extern repv Fnumberp(repv);
 extern repv Fintegerp(repv);
@@ -448,6 +432,7 @@ extern repv Finput_stream_p(repv arg);
 extern repv Foutput_stream_p(repv arg);
 
 /* from symbols.c */
+extern repv rep_undefined_value;
 extern repv (*rep_deref_local_symbol_fun)(repv sym);
 extern repv (*rep_set_local_symbol_fun)(repv sym, repv val);
 extern void rep_intern_static(repv *, repv);
@@ -457,7 +442,7 @@ extern repv rep_bind_symbol(repv, repv, repv);
 extern int rep_unbind_symbols(repv);
 extern repv rep_add_binding_to_env (repv env, repv sym, repv value);
 extern repv rep_obarray;
-extern repv Qnil, Qt;
+extern repv Qt;
 extern repv Qvariable_documentation, Qpermanent_local;
 extern repv rep_void_value;
 extern rep_bool rep_warn_shadowing;
@@ -493,21 +478,25 @@ extern repv Fspecial_variable_p(repv sym);
 extern repv Ftrace(repv sym);
 extern repv Funtrace(repv sym);
 extern repv Vobarray(repv val);
+extern repv Fmake_keyword (repv in);
+extern repv Fkeywordp (repv arg);
 
 /* from structures.c */
 extern repv rep_structure;
-extern repv Fstructure_ref (repv, repv);
-extern repv F_structure_name (repv);
-extern repv F_structurep (repv);
 extern repv Fmake_binding_immutable (repv);
 extern repv Fbinding_immutable_p (repv, repv);
+extern repv Fexport_bindings (repv list);
 extern repv Ffeaturep(repv);
 extern repv Fprovide(repv);
 extern repv Frequire(repv);
+extern repv rep_push_structure_name (repv name);
 extern repv rep_push_structure (const char *name);
 extern repv rep_pop_structure (repv old);
+extern void rep_alias_structure (const char *name);
+extern repv rep_bootstrap_structure (const char *s);
 extern repv rep_add_subr(rep_xsubr *, rep_bool);
 extern void rep_structure_exports_all (repv s, rep_bool status);
+extern void rep_structure_set_binds (repv s, rep_bool status);
 
 /* from tuples.c */
 extern repv rep_make_tuple (repv car, repv a, repv b);
@@ -587,41 +576,14 @@ extern void *rep_find_dl_symbol (repv feature, char *symbol);
 /* from unix_files.c */
 extern repv rep_lookup_errno(void);
 extern u_long rep_file_length(repv file);
-extern repv rep_file_name_absolute_p(repv file);
-extern repv rep_expand_file_name(repv file);
-extern repv rep_canonical_file_name(repv file);
-extern repv rep_file_name_nondirectory(repv file);
-extern repv rep_file_name_directory(repv file);
-extern repv rep_file_name_as_directory(repv file);
-extern repv rep_directory_file_name(repv file);
-extern repv rep_delete_file(repv file);
-extern repv rep_rename_file(repv old, repv new);
-extern repv rep_make_directory(repv dir);
-extern repv rep_delete_directory(repv dir);
-extern repv rep_copy_file(repv src, repv dst);
-extern repv rep_file_readable_p(repv file);
-extern repv rep_file_writable_p(repv file);
-extern repv rep_file_exists_p(repv file);
-extern repv rep_file_regular_p(repv file);
-extern repv rep_file_directory_p(repv file);
-extern repv rep_file_symlink_p(repv file);
-extern repv rep_file_owner_p(repv file);
-extern repv rep_file_nlinks(repv file);
-extern repv rep_file_size(repv file);
-extern repv rep_file_modes(repv file);
-extern repv rep_set_file_modes(repv file, repv modes);
-extern repv rep_file_modes_as_string(repv file);
-extern repv rep_file_modtime(repv file);
-extern repv rep_directory_files(repv dir_name);
-extern repv rep_read_symlink (repv file);
-extern repv rep_make_symlink (repv file, repv contents);
-extern repv rep_getpwd(void);
 
 /* from unix_main.c */
 extern u_long rep_time(void);
 extern rep_long_long rep_utime (void);
+extern u_long rep_getpid (void);
 extern void (*rep_register_input_fd_fun)(int fd, void (*callback)(int fd));
 extern void (*rep_deregister_input_fd_fun)(int fd);
+extern void rep_add_event_loop_callback (rep_bool (*callback)(void));
 extern void rep_sleep_for(long secs, long msecs);
 extern void rep_register_input_fd(int fd, void (*callback)(int fd));
 extern void rep_deregister_input_fd(int fd);
@@ -633,7 +595,12 @@ extern void rep_unix_set_fd_cloexec(int fd);
 extern void rep_sig_restart(int sig, rep_bool flag);
 extern repv rep_event_loop(void);
 extern repv rep_sit_for(u_long timeout_msecs);
-extern repv rep_accept_input(u_long timeout_msecs, void *callback);
+extern repv rep_accept_input_for_callbacks (u_long timeout_msecs,
+					    int ncallbacks,
+					    void (**callbacks)(int));
+extern repv rep_accept_input_for_fds (u_long timeout_msecs,
+				      int nfds, int *fds);
+extern repv rep_accept_input(u_long timeout_msecs, void (*callback)(int));
 extern rep_bool rep_poll_input(int fd);
 
 #ifdef DEBUG_SYS_ALLOC
@@ -687,7 +654,12 @@ extern repv Fprocess_connection_type(repv proc);
 extern repv Fset_process_connection_type(repv proc, repv type);
 extern repv Factive_processes(void);
 extern repv Faccept_process_output(repv secs, repv msecs);
+void rep_register_process_input_handler (void (*handler)(int));
 
 #endif /* rep_HAVE_UNIX */
 
+/* in plugins */
+extern repv rep_dl_init (void);
+extern void rep_dl_kill (void);
+
 #endif /* REP_SUBRS_H */
